Welcome to pyGFE's documentation!
======================================
Copyright (c) 2017 Be The Match operated by National Marrow Donor Program. All Rights Reserved.

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation

   pygfe

   usage
   contributing
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
